@@ -6,7 +6,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 from astropy.io import fits
 from polynomial2d.polynomial2d import Polynomial2D
-import os,glob
+import os,glob,copy
 import json
 
 class Background:
